==> haskell-storable-tuple-0.0.3.3-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-LQxZJRc7Rbb5SbEbkXkl6m
key: storable-tuple-0.0.3.3-LQxZJRc7Rbb5SbEbkXkl6m
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: 153ecf39bcc016fd6767c222f784d6af
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.5/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-LQxZJRc7Rbb5SbEbkXkl6m
depends:
    base-4.12.0.0 base-orphans-0.8.1-ADx13UE5kNMLP8OA0gQSRH
    storable-record-0.0.4-FWs9yvrzelO6WCzQBkZBUX
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-6nt4Gdxmd1s9tNdyqMP2Fb
key: storable-tuple-0.0.3.3-6nt4Gdxmd1s9tNdyqMP2Fb
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: ccc1b6f933b8b5c9f512491861eb96dd
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.5/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-6nt4Gdxmd1s9tNdyqMP2Fb
depends:
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    storable-record-0.0.4-FWs9yvrzelO6WCzQBkZBUX
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
